@@ -14,29 +14,27 @@ you can create many types of objects from which
 "mass" and "spring" are main ones.
 """
 
-import warnings
 import pygame
-from math import sqrt, pi
-import os
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = '1'
+from math import pi, sqrt
+import warnings
+
 
 # variables
 # physical constants
-"""
-dt is delta time -> time difference between two sections; measured in seconds.
-G is newtonian constant of gravitation; measured in m^3*kg^-1*s^-2 or
-    N*m^2*kg^-2 where m is meters, kg is kilograms, s is seconds, N is newtons.
-e0 is vacuum permittivity; measured in m^-2*N^-1*C^2 where m is meters,
-    N is newton, C is coulomb.
-k is coulomb constant(electrostatic constant); measured in m^2*N*C^-2
-    where m is meters, N is newton, C is coulomb.
-Cd is drag coefficient -> 0.47 for sphere; non-united
-da is ro -> density of air; measured in kg*m^-3
-    where kg is kilograms, m is meters.
-ge is earth's gravity acceleration; measured in m*s^-2.
-c is speed of light; measured in m/s where m is meters and s is seconds
-    will be used to check if a mass has exceeded speed limit and raise an error
-"""
+# dt is delta time -> time difference between two sections; measured in seconds.
+# G is newtonian constant of gravitation; measured in m^3*kg^-1*s^-2 or
+#     N*m^2*kg^-2 where m is meters, kg is kilograms, s is seconds, N is newtons.
+# e0 is vacuum permittivity; measured in m^-2*N^-1*C^2 where m is meters,
+#     N is newton, C is coulomb.
+# k is coulomb constant(electrostatic constant); measured in m^2*N*C^-2
+#     where m is meters, N is newton, C is coulomb.
+# Cd is drag coefficient -> 0.47 for sphere; non-united
+# da is ro -> density of air; measured in kg*m^-3
+#     where kg is kilograms, m is meters.
+# ge is earth's gravity acceleration; measured in m*s^-2.
+# c is speed of light; measured in m/s where m is meters and s is seconds
+#     will be used to check if a mass has exceeded speed limit and raise an error
+
 dt = .001
 G = 6.67384e-11
 e0 = 8.854187817e-12
@@ -67,59 +65,6 @@ WINW = 600  # window width  (_)
 WINH = 600  # window height (|)
 WIND = 600  # window depth  (.)
 
-# colors [= ( R ,  G ,  B )]
-WHITE = (255, 255, 255)
-SMOKE = (225, 224, 224)
-DARK_SMOKE = (192, 192, 192)
-SILVER = (157, 157, 157)
-GREY = (128, 128, 128)
-GRAY = GREY
-BLUE_GREY = (94, 124, 139)
-BLUE_GRAY = BLUE_GREY
-BLACK = (0,   0,   0)
-DARK_RED = (128,   0,   0)
-PURE_RED = (255,   0,   0)
-RED = (246,  64,  44)
-PINK = (235,  19,  96)
-PURE_PINK = (255,   0, 128)
-ROSE = (246,  39, 157)
-MAGENTA = (255,   0, 255)
-VIOLET = (238, 130, 239)
-PURPLE = (156,  26, 177)
-PURE_PURPLE = (128,   0, 128)
-DARK_PURPLE = (102,  51, 185)
-INDEGO = (61,  76, 183)
-DARK_BLUE = (0,   0, 128)
-NAVY = DARK_BLUE
-BLUE = (15, 147, 245)
-PURE_BLUE = (0,   0, 255)
-WATER = (0, 166, 246)
-SKY = (140, 220, 250)
-PURE_CYAN = (0, 255, 255)
-AQUA = PURE_CYAN
-CYAN = (0, 187, 213)
-TEAL = (0, 149, 135)
-DARK_CYAN = (0, 128, 128)
-DARK_GREEN = (0, 128,   0)
-GREEN = (70, 175,  74)
-GRASS = (136, 196,  64)
-PURE_GREEN = (0, 255,   0)
-OLIVE = (128, 128,   0)
-LIME = (204, 221,  30)
-YELLOW = (255, 236,  22)
-PURE_YELLOW = (255, 255,   0)
-GOLD = (252, 214,   3)
-PURE_ORANGE = (255, 192,   0)
-AMBER = PURE_ORANGE
-ORANGE = (255, 151,   0)
-DARK_ORANGE = (255,  85,   3)
-BROWN = (121,  84,  70)
-LIGHT_CHOCOLATE = (133,  85,  56)
-PURE_BROWN = (128,  64,   0)
-CHOCOLATE = (105,  58,  42)
-DARK_CHOCOLATE = (72,  51,  50)
-WHITE_CHOCOLATE = (234, 225, 201)
-
 
 # functions
 def hypot3d(x, y, z):
@@ -150,8 +95,15 @@ def assert_type_error_list(obj):
     assert type(obj) == list, TypeError(
         "object list must be from type 'list'")
 
-# Exceptions
 
+def similarity(dx1, dy1, dz1, d1, d2):
+    dx2 = d2 * dx1 / d1
+    dy2 = d2 * dy1 / d1
+    dz2 = d2 * dz1 / d1
+    return dx2, dy2, dz2
+
+
+# Exceptions
 
 class ZeroMass(Exception):
     pass
@@ -360,6 +312,12 @@ class mass(object):
         """ sets the objects forces to 0 """
         self.fx, self.fy, self.fz = 0, 0, 0
 
+    def update_forces(self, fx, fy, fz):
+        """ adds the given forces to the mass """
+        self.fx += fx
+        self.fy += fy
+        self.fz += fz
+
     def set_air_resistance_force(self):
         """ sets the air resistance force to the object """
         if self.resistible:
@@ -367,12 +325,10 @@ class mass(object):
             v = self.v()
             if v == 0:
                 return
-            fx = f * self.vx / v
-            fy = f * self.vy / v
-            fz = f * self.vz / v
-            self.fx -= fx
-            self.fy -= fy
-            self.fz -= fz
+            fx = -f * self.vx / v
+            fy = -f * self.vy / v
+            fz = -f * self.vz / v
+            self.update_forces(fx, fy, fz)
 
     def reflect(self):
         """ reflects the object if it hits the walls """
@@ -607,17 +563,14 @@ class spring(force):
     def set_forces(self):
         """ enters the force to the masses. """
         f = self.force()
-        r, dx, dy, dz = self.d()
-        if r == 0:
+        d, dx, dy, dz = self.d()
+        if d == 0:
             return 0
         m1 = self.m1
         m2 = self.m2
-        m1.fx += f * (dx) / r
-        m1.fy += f * (dy) / r
-        m1.fz += f * (dz) / r
-        m2.fx += f * (-dx) / r
-        m2.fy += f * (-dy) / r
-        m2.fz += f * (-dz) / r
+        fx, fy, fz = similarity(dx, dy, dz, d, f)
+        m1.update_forces(fx, fy, fz)
+        m2.update_forces(-fx, -fy, -fz)
 
     def show_xy(self, win):
         """ method for showing the spring on the screen of x-y coordinates. """
@@ -671,15 +624,9 @@ class gravity(force):
         d, dx, dy, dz = self.d()
         if d == 0:
             return 0
-        fx = f * dx / d
-        fy = f * dy / d
-        fz = f * dz / d
-        self.m1.fx -= fx
-        self.m1.fy -= fy
-        self.m1.fz -= fz
-        self.m2.fx += fx
-        self.m2.fy += fy
-        self.m2.fz += fz
+        fx, fy, fz = similarity(dx, dy, dz, d, f)
+        self.m1.update_forces(-fx, -fy, -fz)
+        self.m2.update_forces(fx, fy, fz)
 
 # electricity
 
@@ -719,15 +666,10 @@ class electricity(force):
         if d == 0:
             return 0
         re = self.re()
-        fx = f * dx / d * re
-        fy = f * dy / d * re
-        fz = f * dz / d * re
-        self.m1.fx += fx
-        self.m1.fy += fy
-        self.m1.fz += fz
-        self.m2.fx -= fx
-        self.m2.fy -= fy
-        self.m2.fz -= fz
+        fx, fy, fz = similarity(dx, dy, dz, d, f)
+        fx, fy, fz = fx * re, fy * re, fz * re
+        self.m1.update_forces(fx, fy, fz)
+        self.m2.update_forces(-fx, -fy, -fz)
 
     def equalise_charge(self):
         """
@@ -736,7 +678,7 @@ class electricity(force):
         """
         if self.m1.conductive and self.m2.conductive:
             q = (self.m1.q + self.m2.q) / 2
-            self.q = q
+            self.m1.q = q
             self.m2.q = q
 
 # collision
@@ -784,12 +726,8 @@ class collision(force):
         v1 = (u1 * (m1 - m2) + u2 * 2 * m2) / (m1 + m2)
         v2 = (u2 * (m2 - m1) + u1 * 2 * m1) / (m1 + m2)
         # dividing v to vx, vy, vz
-        v1x = v1 * dx / d
-        v1y = v1 * dy / d
-        v1z = v1 * dz / d
-        v2x = v2 * -dx / d
-        v2y = v2 * -dy / d
-        v2z = v2 * -dz / d
+        v1x, v1y, v1z = similarity(dx, dy, dz, d, v1)
+        v2x, v2y, v2z = similarity(-dx, -dy, -dz, d, v2)
         # calculating delta v
         dv1x = v1x - u1x
         dv1y = v1y - u1y
@@ -804,13 +742,11 @@ class collision(force):
         a2x = dv2x / dt
         a2y = dv2y / dt
         a2z = dv2z / dt
-        # calculating and adding forces
-        self.m1.fx += a1x * m1
-        self.m1.fy += a1y * m1
-        self.m1.fz += a1z * m1
-        self.m2.fx += a2x * m2
-        self.m2.fy += a2y * m2
-        self.m2.fz += a2z * m2
+        # calculating forces
+        fx1, fy1, fz1 = a1x * m1, a1y * m1, a1z * m1
+        fx2, fy2, fz2 = a2x * m2, a2y * m2, a2z * m2
+        self.m1.update_forces(fx1, fy1, fz1)
+        self.m2.update_forces(fx2, fy2, fz2)
         # the collision is done!
         # equalising the electrical charges of two objects
         # (if they are conductive)
